@@ -15,13 +15,17 @@
 #' @importFrom mime guess_type
 #' @importFrom rmarkdown render html_document
 #' @importFrom stats setNames na.omit
-#' @importFrom stringi stri_replace_all_fixed stri_replace_all_regex
+#' @importFrom stringi stri_replace_all_fixed stri_replace_all_regex stri_enc_mark stri_trans_nfkc
 #' @importFrom tools file_ext
 #' @importFrom urltools url_decode
 #' @importFrom utils packageVersion download.file modifyList
 #' @importFrom xfun read_utf8
 NULL
 
+.onLoad <- function(libname, pkgname) {                             # nolint
+  log_layout(layout_glue_generator('{stringr::str_pad(level, 7, side = "right")} [{time}] {msg}')) # nocov
+}
+
 globalVariables(
   c(
     ".",
@@ -30,6 +34,7 @@ globalVariables(
     "fingerprint",
     "msg",
     "runif",
-    "detect_language"
+    "detect_language",
+    "timestamp"
   )
 )
